==> kf6-libkdegames-24.12.3.tgz: lib/cmake/KDEGames6/KDEGames6Targets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDEGames6Private" for configuration "Release"
set_property(TARGET KDEGames6Private APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDEGames6Private PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF6::DNSSD;KF6::I18n;KF6::Archive;KF6::CoreAddons;KF6::XmlGui"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDEGames6Private.so.0.0"
  IMPORTED_SONAME_RELEASE "libKDEGames6Private.so.0.0"
  )

list(APPEND _cmake_import_check_targets KDEGames6Private )
list(APPEND _cmake_import_check_files_for_KDEGames6Private "${_IMPORT_PREFIX}/lib/libKDEGames6Private.so.0.0" )

# Import target "KDEGames6" for configuration "Release"
set_property(TARGET KDEGames6 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDEGames6 PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF6::NewStuffWidgets;KF6::IconThemes;KF6::I18n;KF6::XmlGui;KF6::GuiAddons;KF6::Completion;Qt6::Xml;Qt6::Svg;Qt6::Quick"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDEGames6.so.0.0"
  IMPORTED_SONAME_RELEASE "libKDEGames6.so.0.0"
  )

list(APPEND _cmake_import_check_targets KDEGames6 )
list(APPEND _cmake_import_check_files_for_KDEGames6 "${_IMPORT_PREFIX}/lib/libKDEGames6.so.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> kf6-libkdegames-25.08.3.tgz: lib/cmake/KDEGames6/KDEGames6Targets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDEGames6Private" for configuration "Release"
set_property(TARGET KDEGames6Private APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDEGames6Private PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF6::DNSSD;KF6::I18n;KF6::Archive;KF6::CoreAddons;KF6::XmlGui"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDEGames6Private.so.0.0"
  IMPORTED_SONAME_RELEASE "libKDEGames6Private.so.0.0"
  )

list(APPEND _cmake_import_check_targets KDEGames6Private )
list(APPEND _cmake_import_check_files_for_KDEGames6Private "${_IMPORT_PREFIX}/lib/libKDEGames6Private.so.0.0" )

# Import target "KDEGames6" for configuration "Release"
set_property(TARGET KDEGames6 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDEGames6 PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF6::NewStuffWidgets;KF6::IconThemes;KF6::I18n;KF6::XmlGui;KF6::GuiAddons;KF6::Completion;KF6::ColorScheme;Qt6::Xml;Qt6::Svg;Qt6::Quick"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKDEGames6.so.0.0"
  IMPORTED_SONAME_RELEASE "libKDEGames6.so.0.0"
  )

list(APPEND _cmake_import_check_targets KDEGames6 )
list(APPEND _cmake_import_check_files_for_KDEGames6 "${_IMPORT_PREFIX}/lib/libKDEGames6.so.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
